import { GLOBSTAR } from './index.js';
export type MMPattern = string | RegExp | typeof GLOBSTAR;
export interface MiniOpts {
    dot?: boolean;
    nocase?: boolean;
    noext?: boolean;
    noglobstar?: boolean;
    nobrace?: boolean;
    windowsPathsNoEscape?: boolean;
    platform?: typeof process.platform;
}
export declare class Mini {
    options: MiniOpts;
    globLists: GlobList[];
    patterns: Pattern[];
    dot: boolean;
    nocase: boolean;
    noext: boolean;
    noglobstar: boolean;
    nobrace: boolean;
    windowsPathsNoEscape: boolean;
    platform: typeof process.platform;
    isWindows: boolean;
    constructor(patterns: string | string[], opts?: MiniOpts);
    splitGlobString(globString: string): string[];
    isDrive(pl: string[]): boolean;
    isUNC(pl: string[]): boolean;
    preprocess(globParts: string[][]): string[][];
    firstPhasePreProcess(globParts: string[][]): string[][];
    secondPhasePreProcess(globParts: string[][]): string[][];
    partsMatch(a: string[], b: string[]): false | string[];
}
export declare const braceExpand: (pattern: string, options?: MiniOpts) => string[];
type GlobList = [p: string, ...rest: string[]];
type Parsed = Map<string, MMPattern>;
export declare class Pattern {
    #private;
    readonly length: number;
    constructor(globList: GlobList, index: number, parsed: Parsed, options: MiniOpts);
    glob(): string;
    pattern(): MMPattern;
    isAbsolute(): boolean;
    root(): string;
    rest(): Pattern | null;
    hasMore(): this is PatternWithMore;
}
interface PatternWithMore extends Pattern {
    rest(): Pattern;
}
export declare const parsePattern: (pattern: string, options: MiniOpts) => MMPattern;
export declare const compile: (ast: AST, options: MiniOpts, isTop?: boolean, isStart?: boolean) => string;
type AST = Token[];
type ExtToken = [t: TokenType.EXT, value: ExtGlobType, children: AST[]];
type StringToken = [t: TokenType.STRING, value: string];
type StarToken = [t: TokenType.STAR, value: '*'];
type QmarkToken = [t: TokenType.QMARK, value: '?'];
type ClassToken = [t: TokenType.CLASS, value: string];
type Token = ExtToken | StringToken | StarToken | QmarkToken | ClassToken;
declare enum TokenType {
    STRING = "string",
    STAR = "star",
    EXT = "ext",
    QMARK = "qmark",
    CLASS = "class"
}
type ExtGlobType = '?' | '*' | '+' | '@' | '!';
export declare const tokenize: (pattern: string, options: MiniOpts, ast?: AST) => AST;
export {};
